from django.contrib import admin
from djangodblog.models import ErrorBatch, Error

class ErrorBatchAdmin(admin.ModelAdmin):
    list_display    = ('class_name', 'is_resolved', 'message', 'last_seen', 'times_seen', 'url', 'server_name')
    list_filter     = ('class_name', 'times_seen', 'server_name', 'is_resolved')
    ordering        = ('-last_seen',)

class ErrorAdmin(admin.ModelAdmin):
    list_display    = ('class_name', 'message', 'datetime', 'url', 'server_name')
    list_filter     = ('class_name', 'datetime', 'server_name')
    ordering        = ('-datetime',)

admin.site.register(ErrorBatch, ErrorBatchAdmin)
admin.site.register(Error, ErrorAdmin)



import traceback
import socket
import warnings

from django.conf import settings
from django.http import Http404
from django.utils.hashcompat import md5_constructor

from djangodblog.models import Error, ErrorBatch

__all__ = ('DBLogMiddleware', 'DBLOG_CATCH_404_ERRORS')

DBLOG_CATCH_404_ERRORS = getattr(settings, 'DBLOG_CATCH_404_ERRORS', False)

class DBLogMiddleware(object):
    def process_exception(self, request, exception):
        if not DBLOG_CATCH_404_ERRORS and isinstance(exception, Http404):
            return
        server_name = socket.gethostname()
        tb_text     = traceback.format_exc()
        class_name  = exception.__class__.__name__
        checksum    = md5_constructor(tb_text).hexdigest()

        defaults = dict(
            class_name  = class_name,
            message     = getattr(exception, 'message', ''),
            url         = request.build_absolute_uri(),
            server_name = server_name,
            traceback   = tb_text,
        )

        try:
            Error.objects.create(**defaults)
            batch, created = ErrorBatch.objects.get_or_create(
                class_name = class_name,
                server_name = server_name,
                checksum = checksum,
                defaults = defaults
            )
            if not created:
                batch.times_seen += 1
                batch.resolved = False
                batch.save()
        except Exception, exc:
            warnings.warn(unicode(exc))


#!/usr/bin/env python

from distutils.core import setup

setup(name='django-db-log',
      version='1.0.1',
      description='Django DB Error Logging',
      author='David Cramer',
      author_email='dcramer@gmail.com',
      url='http://code.google.com/p/django-db-log/',
      packages=['djangodblog'],
     )



from django.db import models
from django.utils.translation import ugettext_lazy as _

import datetime

__all__ = ('Error', 'ErrorBatch')

class ErrorBatch(models.Model):
    class_name      = models.CharField(_('Type'), max_length=128)
    message         = models.TextField()
    traceback       = models.TextField()
    is_resolved     = models.BooleanField(default=False)
    times_seen      = models.PositiveIntegerField(default=1)
    last_seen       = models.DateTimeField(default=datetime.datetime.now)
    first_seen      = models.DateTimeField(default=datetime.datetime.now)
    url             = models.URLField(verify_exists=False, null=True, blank=True)
    server_name     = models.CharField(max_length=128, db_index=True)
    checksum        = models.CharField(max_length=32, db_index=True)

    class Meta:
        unique_together = (('class_name', 'server_name', 'checksum'),)

class Error(models.Model):
    class_name      = models.CharField(_('type'), max_length=128)
    message         = models.TextField()
    traceback       = models.TextField()
    datetime        = models.DateTimeField(default=datetime.datetime.now)
    url             = models.URLField(verify_exists=False, null=True, blank=True)
    server_name     = models.CharField(max_length=128, db_index=True)